# -*- coding: utf-8 -*-

import os
import sys

sys.path.insert(0, os.path.abspath('.'))
extensions = ['enumerable_node']

master_doc = 'index'
numfig = True
